@@ -30,10 +30,10 @@ def _f_impl_1_euler_direct(x0, Y0, dx, jac=None, *args, **kwargs):
     ---|---
        | 1 
     """
-    if jac is None:
-        jac = Y0.jacobian(x0 + dx)
-    N = jac.shape[0]
-    eye = np.eye(N)
+    jac = Y0.jacobian(x0 + dx) if jac is None else jac  # Jacobain
+    N = jac.shape[0]                                    # Problem size
+    eye = np.eye(N)                                     # Identity matrix
+
     A = eye - dx[0] * jac
     return (np.linalg.inv(A) - eye) @ Y0
 
