@@ -4,7 +4,7 @@ import numpy as np
 from scipy.sparse import linalg
 
 
-def _f_impl_1_euler_gmres(x0, Y0, dx, jac=None, gmres_opt={}, *args, **kwargs):
+def _f_impl_1_euler_gmres(x0, Y0, dx, jac=None, gmres_opt={"atol": 0.}, *args, **kwargs):
     """Implicit 1st-order Euler integration scheme with GMRES solver
 
     Parameters
@@ -17,7 +17,7 @@ def _f_impl_1_euler_gmres(x0, Y0, dx, jac=None, gmres_opt={}, *args, **kwargs):
         Stepsize of integration variable
     jac : Field, optional, defaul : None
         Current Jacobian. Will be calculated, if not set
-    gmres_opt : dict, optional, default : {}
+    gmres_opt : dict, optional, default : {"atol": 0.}
         dictionary with options for scipy GMRES solver
     args : additional positional arguments
     kwargs : additional keyworda arguments
@@ -33,10 +33,10 @@ def _f_impl_1_euler_gmres(x0, Y0, dx, jac=None, gmres_opt={}, *args, **kwargs):
     ---|---
        | 1 
     """
-    if jac is None:
-        jac = Y0.jacobian(x0 + dx)
-    N = jac.shape[0]
-    eye = np.eye(N)
+    jac = Y0.jacobian(x0 + dx) if jac is None else jac  # Jacobain
+    N = jac.shape[0]                                    # Problem size
+    eye = np.eye(N)                                     # Identity matrix
+
     A = eye - dx*jac
     res, state = linalg.gmres(A, Y0, **gmres_opt)
     if state != 0:
