@@ -30,10 +30,9 @@ def _f_impl_2_midpoint_direct(x0, Y0, dx, jac=None, *args, **kwargs):
     -----|-----
          |  1 
     """
-    if jac is None:
-        jac = Y0.jacobian(x0+0.5*dx)    # Jacobian
-    N = jac.shape[0]                    # Problem size
-    eye = np.eye(N)                     # Identity matrix
+    jac = Y0.jacobian(x0 + dx) if jac is None else jac  # Jacobain
+    N = jac.shape[0]                                    # Problem size
+    eye = np.eye(N)                                     # Identity matrix
 
     A = eye - 0.5*dx*jac
     Ainv = np.linalg.inv(A)
