@@ -1,3 +1,4 @@
+import copy
 from datetime import timedelta
 from itertools import cycle
 import numpy as np
@@ -89,7 +90,7 @@ class Progressbar(object):
                 :self._N_speed]
             self._speed = self._speedbuffer.mean()
         self._t = t
-        self._x = x.copy()
+        self._x = copy.copy(x)
 
     def _geteta(self, x, s1):
         '''Returns the current ETA
@@ -108,9 +109,12 @@ class Progressbar(object):
         self._update_speed(x)
         if self._speed is None:
             return ""
-        eta = (s1-x)/self._speed
+        if self._speed > 0.:
+            eta = (s1-x)/self._speed
+        else:
+            eta = np.nan
         try:
-            dt = timedelta(seconds=np.int(eta))
+            dt = timedelta(seconds=int(eta))
         except:
             dt = "N/A"
         ret = "ETA: {}".format(dt)
@@ -135,7 +139,7 @@ class Progressbar(object):
         line : string
             Progress bar line"""
         f = (x-x0)/(x1-x0)
-        filled = np.int(np.floor(f*self._length))
+        filled = int(np.floor(f*self._length))
         line = "{:10s}{}{:5.1f} %".format(text, self._getbar(filled), f*100.)
         return line
 
